Term

Enum Term 

pub enum Term {
    BlankId(BlankIdBuf),
    Ground(GroundTerm),
}
Term.

Lexical representation of an RDF resource.

Variants



BlankId(BlankIdBuf)

Blank identifier.



Ground(GroundTerm)

Ground term.

Implementations

Source

impl Term

pub fn iri(iri: IriBuf) -> Self

Creates an IRI term.

pub fn literal(literal: Literal) -> Self

Creates a literal term.

pub fn id(id: Id) -> Self

Creates a term from an identifier (IRI or blank node identifier).

pub fn is_id(&self) -> bool

Checks if this term is an identifier, i.e. a blank node identifier or an IRI (as opposed to a literal).

pub fn as_id(&self) -> Option<IdRef<'_>>

Returns this term as an identifier, unless it is a literal.

pub fn is_blank_id(&self) -> bool

Checks if this is a blank node identifier.

pub fn is_ground(&self) -> bool

Checks if this is a ground term (an IRI or a literal, but not a blank node identifier).

pub fn as_blank_id(&self) -> Option<&BlankId>

Returns this term as a blank node identifier, if it is one.

pub fn as_ground(&self) -> Option<&GroundTerm>

Returns this term as a ground term, if it is one.

pub fn into_ground(self) -> Result<GroundTerm, BlankIdBuf>

Turns this term into a ground term, or returns the blank node identifier if it isn’t one.

pub fn is_iri(&self) -> bool

Checks if this is an IRI.

pub fn as_iri(&self) -> Option<&Iri>

Returns this term as an IRI, if it is one.

pub fn into_iri(self) -> Result<IriBuf, Self>

Turns this term into an IRI, or returns it unchanged if it isn’t one.

pub fn is_literal(&self) -> bool

Checks if this is a literal.

pub fn as_literal(&self) -> Option<LiteralRef<'_>>

Returns this term as a literal, if it is one.

pub fn as_ref(&self) -> TermRef<'_>

Returns a reference to this term.

pub fn as_cow(&self) -> CowTerm<'_>

Returns a copy-on-write reference to this term.

pub fn into_cow(self) -> CowTerm<'static>

Turns this term into a copy-on-write term.

pub fn into_id(self) -> Result<Id, Literal>

Turns this term into an identifier, or returns the literal value if it isn’t one.