pub enum TermRef<'a> {
BlankId(&'a BlankId),
Ground(GroundTermRef<'a>),
}Expand description
Term reference.
Variants
Implementations
Sourceimpl<'a> TermRef<'a>
impl<'a> TermRef<'a>
Sourcepub fn is_id(&self) -> bool
pub fn is_id(&self) -> bool
Checks if this term is an identifier, i.e. a blank node identifier or an IRI (as opposed to a literal).
Sourcepub fn as_id(&self) -> Option<IdRef<'a>>
pub fn as_id(&self) -> Option<IdRef<'a>>
Returns this term as an identifier, unless it is a literal.
Sourcepub fn into_id(self) -> Result<IdRef<'a>, LiteralRef<'a>>
pub fn into_id(self) -> Result<IdRef<'a>, LiteralRef<'a>>
Turns this term into an identifier, or returns the literal value if it isn’t one.
Sourcepub fn is_blank_id(&self) -> bool
pub fn is_blank_id(&self) -> bool
Checks if this is a blank node identifier.
Sourcepub fn is_ground(&self) -> bool
pub fn is_ground(&self) -> bool
Checks if this is a ground term (an IRI or a literal, but not a blank node identifier).
Sourcepub fn is_literal(&self) -> bool
pub fn is_literal(&self) -> bool
Checks if this is a literal.
Sourcepub fn as_blank_id(&self) -> Option<&'a BlankId>
pub fn as_blank_id(&self) -> Option<&'a BlankId>
Returns this term as a blank node identifier, if it is one.
Sourcepub fn as_ground(&self) -> Option<GroundTermRef<'a>>
pub fn as_ground(&self) -> Option<GroundTermRef<'a>>
Returns this term as a ground term, if it is one.
Sourcepub fn as_literal(&self) -> Option<LiteralRef<'a>>
pub fn as_literal(&self) -> Option<LiteralRef<'a>>
Returns this term as a literal, if it is one.
Sourcepub fn into_ground(self) -> Result<GroundTermRef<'a>, &'a BlankId>
pub fn into_ground(self) -> Result<GroundTermRef<'a>, &'a BlankId>
Turns this term into a ground term, or returns the blank node identifier if it isn’t one.