Query

Struct Query 

pub struct Query(/* private fields */);
IRI query.

Implementations

Source

impl Query

pub const fn validate_str(input: &str) -> bool

pub const fn validate_bytes(input: &[u8]) -> bool

Source

impl Query

pub fn new<T>(input: &T) -> Result<&Query, InvalidQuery<&T>>
where T: AsRef<[u8]> + ?Sized,

Creates a new query by parsing the input value.

pub const fn from_bytes(input: &[u8]) -> Result<&Query, InvalidQuery<&[u8]>>

Creates a new query by parsing the input bytes.

pub const fn from_str(input: &str) -> Result<&Query, InvalidQuery<&str>>

Creates a new query by parsing the input string.

pub const unsafe fn new_unchecked_from_bytes(input: &[u8]) -> &Query

Creates a new query from the input bytes without validation.

Safety

The input bytes must be a valid query.

pub const unsafe fn new_unchecked(input: &str) -> &Query

Creates a new query from the input string without validation.

Safety

The input string must be a valid query.

Source

impl Query

pub const fn as_str(&self) -> &str

Returns the query as a string.

pub const fn as_bytes(&self) -> &[u8]

Returns the query as a byte string.

Source

impl Query

pub const EMPTY: &'static Query

The empty query.

pub fn as_pct_str(&self) -> &PctStr

Returns the query as a percent-encoded string slice.

Methods from Deref<Target = PctStr>

pub fn len(&self) -> usize

Length of the decoded string (character count).

Computed in linear time. This is different from the byte length, which can be retrieved using value.as_bytes().len().

pub fn is_empty(&self) -> bool

Checks if the string is empty.

pub fn as_bytes(&self) -> &[u8]

Returns the underlying percent-encoding bytes.

pub fn as_str(&self) -> &str

Get the underlying percent-encoded string slice.

pub fn chars(&self) -> Chars<'_>

Iterate over the encoded characters of the string.

pub fn bytes(&self) -> Bytes<'_>

Iterate over the encoded bytes of the string.

pub fn decode(&self) -> String

Decoding.

Return the string with the percent-encoded characters decoded.