WithGenerator

Struct WithGenerator 

pub struct WithGenerator<G, I = StaticDomain<Term>> { /* private fields */ }
Combines any RDF interpretation with a node id generator.

  • Provides a GenDomain implementation, using the given generator to create fresh node identifiers.
  • Assigns a node identifier to each new resource created by GenDomain::new_resource, based on the generator.

Note that in the case of the unit (()) interpretation, using GenDomain will give you a similar result but with other advantages (such as a ConstGenDomain implementation).

Implementations

Source

impl<G, I> WithGenerator<G, I>

pub fn new(interpretation: I, generator: G) -> Self

Combines the given interpretation with the given generator.

pub fn into_parts(self) -> (I, G)

Discards this wrapper, returning the inner interpretation and generator.

pub fn inner_interpretation(&self) -> &I

Returns a reference to the inner interpretation.

pub fn inner_interpretation_mut(&mut self) -> &mut I

Returns a mutable reference to the inner interpretation.

pub fn generator(&self) -> &G

Returns a reference to the inner generator.

pub fn generator_mut(&mut self) -> &mut G

Returns a mutable reference to the inner generator.

pub fn into_inner_interpretation(self) -> I

Discards this wrapper and the generator, returning the inner interpretation.

pub fn into_generator(self) -> G

Discards this wrapper and the interpretation, returning the inner generator.