PredicateFiniteGraph

Trait PredicateFiniteGraph 

pub trait PredicateFiniteGraph: Graph {
    type GraphPredicates<'a>: Iterator<Item = &'a Self::Resource>
       where Self: 'a;

    // Required method
    fn graph_predicates(&self) -> Self::GraphPredicates<'_>;

    // Provided method
    fn graph_predicate_count(&self) -> usize { ... }
}
Graph that can enumerate the distinct resources it uses as a predicate.

Required Associated Types

type GraphPredicates<'a>: Iterator<Item = &'a Self::Resource> where Self: 'a

Predicates iterator.

Required Methods

fn graph_predicates(&self) -> Self::GraphPredicates<'_>

Returns an iterator over the distinct predicates of the graph.

Provided Methods

fn graph_predicate_count(&self) -> usize

Returns the number of distinct predicates in the graph.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors