TryGraphMut

Trait TryGraphMut 

pub trait TryGraphMut: TryGraph {
    // Required method
    fn try_insert(
        &mut self,
        triple: Triple<Self::Resource>,
    ) -> Result<(), Self::Error>;
}
Fallible mutable graph.

Required Methods

fn try_insert( &mut self, triple: Triple<Self::Resource>, ) -> Result<(), Self::Error>

Tries to insert the given triple in the graph.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<D> TryGraphMut for D
where D: GraphMut,

Any non-fallible mutable graph can be used as fallible, with the Infallible error type.