pub enum Term {
BlankId(BlankIdBuf),
Ground(GroundTerm),
}Expand description
Term.
Lexical representation of an RDF resource.
Variants
Implementations
Sourceimpl Term
impl Term
Sourcepub fn is_id(&self) -> bool
pub fn is_id(&self) -> bool
Checks if this term is an identifier, i.e. a blank node identifier or an IRI (as opposed to a literal).
Sourcepub fn as_id(&self) -> Option<IdRef<'_>>
pub fn as_id(&self) -> Option<IdRef<'_>>
Returns this term as an identifier, unless it is a literal.
Sourcepub fn is_blank_id(&self) -> bool
pub fn is_blank_id(&self) -> bool
Checks if this is a blank node identifier.
Sourcepub fn is_ground(&self) -> bool
pub fn is_ground(&self) -> bool
Checks if this is a ground term (an IRI or a literal, but not a blank node identifier).
Sourcepub fn as_blank_id(&self) -> Option<&BlankId>
pub fn as_blank_id(&self) -> Option<&BlankId>
Returns this term as a blank node identifier, if it is one.
Sourcepub fn as_ground(&self) -> Option<&GroundTerm>
pub fn as_ground(&self) -> Option<&GroundTerm>
Returns this term as a ground term, if it is one.
Sourcepub fn into_ground(self) -> Result<GroundTerm, BlankIdBuf>
pub fn into_ground(self) -> Result<GroundTerm, BlankIdBuf>
Turns this term into a ground term, or returns the blank node identifier if it isn’t one.
Sourcepub fn into_iri(self) -> Result<IriBuf, Self>
pub fn into_iri(self) -> Result<IriBuf, Self>
Turns this term into an IRI, or returns it unchanged if it isn’t one.
Sourcepub fn is_literal(&self) -> bool
pub fn is_literal(&self) -> bool
Checks if this is a literal.
Sourcepub fn as_literal(&self) -> Option<LiteralRef<'_>>
pub fn as_literal(&self) -> Option<LiteralRef<'_>>
Returns this term as a literal, if it is one.