pub struct BTreeGraph<R> { /* private fields */ }Expand description
BTree-based RDF graph.
Implementations
Sourceimpl<R> BTreeGraph<R>
impl<R> BTreeGraph<R>
Sourcepub fn new() -> BTreeGraph<R>
pub fn new() -> BTreeGraph<R>
Creates a new empty graph.
Sourcepub fn resources(&self) -> Resources<'_, R> ⓘ
pub fn resources(&self) -> Resources<'_, R> ⓘ
Returns an iterator over the resources of the graph.
Sourcepub fn into_indexed(self) -> IndexedBTreeGraph<R>
pub fn into_indexed(self) -> IndexedBTreeGraph<R>
Indexes the triples to allow more operation on this graph, such as
pattern matching using the PatternMatchingGraph trait.
Sourceimpl<R> BTreeGraph<R>where
R: Ord,
impl<R> BTreeGraph<R>where
R: Ord,
Sourcepub fn contains_resource(&self, resource: &R) -> bool
pub fn contains_resource(&self, resource: &R) -> bool
Checks if the provided resource appears in any triple in the graph.
Sourcepub fn contains(&self, triple: Triple<&R>) -> bool
pub fn contains(&self, triple: Triple<&R>) -> bool
Checks if the provided triple is in the graph.