pub struct StaticDomain<R>(/* private fields */);Expand description
Trivial domain implementation that just fixes the resource type R,
without tracking any actual resource.
Useful whenever a Domain is required by a trait bound but no
domain-specific behavior (finiteness, generation, etc.) is needed, or as
a default/building block for other, more specific domains.
Implementations
Sourceimpl<R> StaticDomain<R>
impl<R> StaticDomain<R>
Sourcepub fn new() -> StaticDomain<R>
pub fn new() -> StaticDomain<R>
Creates a new static domain.